@@ -21,6 +21,10 @@ def weighting(dm):
     kj = 'kj'
     qj = 'qj'
     wj = 'wj'
+    for i in range(1, number_of_judge+1):
+        df.loc[0,sj+str(i)] = 0
+        df[kj+str(i)] = df[sj+str(i)].astype('float') + 1
+        df.loc[0,sj+str(i)] = '*'
     for j in range(1,number_of_judge+1):
         for i in range(0,len(df)):
             if i == 0:
